==> 0.1.0.zip: data/data.php <==
<?php
/*
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
*/
// Polyfill for PHP 4 - PHP 7, safe to utilize with PHP 8
if (!function_exists('str_contains')) {
    function str_contains($haystack, $needle) {
        return $needle !== '' && mb_strpos($haystack, $needle) !== false;
    }
}

$function = $_POST["function"];
if (str_contains($function, 'addUser')) {
	$data = $_POST['data'];
	$nameToAdd = $data['nameToAdd'];
	$pwdToAdd = $data['pwdToAdd'];
	$adminToAdd = $data['adminToAdd'];
	$pagesToAdd = $data['pagesToAdd'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour ajouter un utilisateur
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$tmp = json_decode($file_data, true);
				$tmp[$nameToAdd]['pwd'] = $pwdToAdd;
				$tmp[$nameToAdd]['admin'] = ($adminToAdd === 'true');
				$tmp[$nameToAdd]['pages'] = $pagesToAdd;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'removeUser')) {
	$data = $_POST['data'];
	$nameToRemove = $data['nameToRemove'];
	$name = $data['name'];
	if(strcmp($name, $nameToRemove) == 0) {
		echo -2; //On ne peux pas se supprimer soi-même
	}
	else {
		$pwd = $data['pwd'];
		$file = "users.json";
		$file_data = file_get_contents($file);
		//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour supprimer un utilisateur
		if(filesize($file)) {
			$tmp = json_decode($file_data, true);
			if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
				if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
					$tmp = json_decode($file_data, true);
					unset($tmp[$nameToRemove]);
					$new_data = json_encode($tmp);
					$fp = fopen($file, 'w');
					fwrite($fp, $new_data);
					fclose($fp);
					echo 0;
				}
				else {
					echo -1;
				}
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
} elseif (str_contains($function, 'checkPassword')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			echo strcmp($tmp[$name]['pwd'], $pwd);
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'changePassword')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$new_pwd = $data['new_pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0) {
				$tmp = json_decode($file_data, true);
				$tmp[$name]['pwd'] = $new_pwd;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'isAdmin')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			echo $tmp[$name]['admin'];
		}
	}
} elseif (str_contains($function, 'getPages')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			header('Content-Type: application/json; charset=utf-8');
			echo json_encode($tmp[$name]['pages']);
		}
	}
} elseif (str_contains($function, 'getUsers')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour obtenir la liste des utilisateurs
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				header('Content-Type: application/json; charset=utf-8');
				echo $file_data;
			}
		}
	}
} elseif (str_contains($function, 'getDB')) {
	$file = file_get_contents("db.json");
	header('Content-Type: application/json; charset=utf-8');
	echo $file;
} elseif (str_contains($function, 'updateSettings')) {
	$data = $_POST['data'];
	$nom = $data['nom'];
	$description = $data['description'];
	$keywords = $data['keywords'];
	$player = $data['player'];
	$footer = $data['copyright'];
	$logo = $data['logo'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['nom'] = $nom;
				$tmp['description'] = $description;
				$tmp['keywords'] = $keywords;
				$tmp['urlPlayer'] = $player;
				$tmp['footer'] = $footer;
				$tmp['logo'] = $logo;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateCarousels')) {
	$data = $_POST['data'];
	$carousels = $data['carousels'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['carousels'] = $carousels;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updatePages')) {
	$data = $_POST['data'];
	$pages = $data['pages'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['pages'] = $pages;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updatePage')) {
	$data = $_POST['data'];
	$page = $data['page'];
	$nom = $data['nom'];
	$contenu = $data['contenu'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['pages'][$page]['nom'] = $nom;
				$tmp['pages'][$page]['contenu'] = $contenu;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateHeader')) {
	$data = $_POST['data'];
	$header = $data['header'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['liensHeader'] = $header;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateFooter')) {
	$data = $_POST['data'];
	$footer = $data['footer'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['liensFooter'] = $footer;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'getURLPlayer')) {
	$file = "db.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		echo $tmp['urlPlayer'];
	}
} elseif (str_contains($function, 'getImages')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
			    $all_files = glob("../images/upload/*.*");
			    $img = array();
			    for ($i=0; $i<count($all_files); $i++)
			    {
			        $image_name = $all_files[$i];
			        $supported_format = array('gif','jpg','jpeg','png');
			        $ext = strtolower(pathinfo($image_name, PATHINFO_EXTENSION));
			        if (in_array($ext, $supported_format))
			        {
			            array_push($img, $image_name);
			        } else {
			            continue;
			        }
			    }
			    header('Content-Type: application/json; charset=utf-8');
			    echo json_encode($img);
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'removeImage')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$img = $data['img'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				if (file_exists($img)) {
	                if (unlink($img)) {
	                	echo 0;
	                }
	                else {
	                	echo -1;
	                }
	            }
	            else {
	            	echo -1; 
	            }
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'addPage')) {
	$data = $_POST['data'];
	$id = $data['id'];
	$nom = $data['nom'];
	$contenu = $data['contenu'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour ajouter un utilisateur
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$tmp = json_decode(file_get_contents("db.json"), true);
				$tmp['pages'][$id]['nom'] = $nom;
				$tmp['pages'][$id]['contenu'] = $contenu;
				$new_data = json_encode($tmp);
				echo $new_data . ' ';
				$fp = fopen("db.json", 'w');
				echo fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "db.json";
	$data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($data, true);
		$tmp[$name] = $pwd;
		$data = json_encode($tmp);
	}
	else {
		$data = json_encode(array($name => $pwd));
	}
}
?>

==> 0.1.3.zip: data/data.php <==
<?php
/*
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
*/
// Polyfill for PHP 4 - PHP 7, safe to utilize with PHP 8
if (!function_exists('str_contains')) {
    function str_contains($haystack, $needle) {
        return $needle !== '' && mb_strpos($haystack, $needle) !== false;
    }
}

$function = $_POST["function"];
if (str_contains($function, 'addUser')) {
	$data = $_POST['data'];
	$nameToAdd = $data['nameToAdd'];
	$pwdToAdd = $data['pwdToAdd'];
	$adminToAdd = $data['adminToAdd'];
	$pagesToAdd = $data['pagesToAdd'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour ajouter un utilisateur
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$tmp = json_decode($file_data, true);
				$tmp[$nameToAdd]['pwd'] = $pwdToAdd;
				$tmp[$nameToAdd]['admin'] = ($adminToAdd === 'true');
				$tmp[$nameToAdd]['pages'] = $pagesToAdd;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'removeUser')) {
	$data = $_POST['data'];
	$nameToRemove = $data['nameToRemove'];
	$name = $data['name'];
	if(strcmp($name, $nameToRemove) == 0) {
		echo -2; //On ne peux pas se supprimer soi-même
	}
	else {
		$pwd = $data['pwd'];
		$file = "users.json";
		$file_data = file_get_contents($file);
		//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour supprimer un utilisateur
		if(filesize($file)) {
			$tmp = json_decode($file_data, true);
			if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
				if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
					$tmp = json_decode($file_data, true);
					unset($tmp[$nameToRemove]);
					$new_data = json_encode($tmp);
					$fp = fopen($file, 'w');
					fwrite($fp, $new_data);
					fclose($fp);
					echo 0;
				}
				else {
					echo -1;
				}
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
} elseif (str_contains($function, 'checkPassword')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			echo strcmp($tmp[$name]['pwd'], $pwd);
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'changePassword')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$new_pwd = $data['new_pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0) {
				$tmp = json_decode($file_data, true);
				$tmp[$name]['pwd'] = $new_pwd;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'isAdmin')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			echo $tmp[$name]['admin'];
		}
	}
} elseif (str_contains($function, 'getPage')) {
	$page = $_POST['page'];
    $file = file_get_contents("db.json");
    $tmp = json_decode($file, true);
    header('Content-Type: application/json; charset=utf-8');
    echo json_encode($tmp['pages'][$page]);
} elseif (str_contains($function, 'getUsers')) {
	$page = $_POST['page'];
	$file = file_get_contents("db.json");
	header('Content-Type: application/json; charset=utf-8');
	echo $file;
} elseif (str_contains($function, 'getDB')) {
	$file = file_get_contents("db.json");
	header('Content-Type: application/json; charset=utf-8');
	echo $file;
} elseif (str_contains($function, 'updateSettings')) {
	$data = $_POST['data'];
	$nom = $data['nom'];
	$description = $data['description'];
	$keywords = $data['keywords'];
	$player = $data['player'];
	$footer = $data['copyright'];
	$logo = $data['logo'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['nom'] = $nom;
				$tmp['description'] = $description;
				$tmp['keywords'] = $keywords;
				$tmp['urlPlayer'] = $player;
				$tmp['footer'] = $footer;
				$tmp['logo'] = $logo;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateCarousels')) {
	$data = $_POST['data'];
	$carousels = $data['carousels'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['carousels'] = $carousels;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updatePages')) {
	$data = $_POST['data'];
	$pages = $data['pages'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['pages'] = $pages;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updatePage')) {
	$data = $_POST['data'];
	$page = $data['page'];
	$nom = $data['nom'];
	$contenu = $data['contenu'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['pages'][$page]['nom'] = $nom;
				$tmp['pages'][$page]['contenu'] = $contenu;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateHeader')) {
	$data = $_POST['data'];
	$header = $data['header'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['liensHeader'] = $header;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'updateFooter')) {
	$data = $_POST['data'];
	$footer = $data['footer'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$file = "db.json";
				$file_data = file_get_contents($file);
				$tmp = json_decode($file_data, true);
				$tmp['liensFooter'] = $footer;
				$new_data = json_encode($tmp);
				$fp = fopen($file, 'w');
				fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'getURLPlayer')) {
	$file = "db.json";
	$file_data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		echo $tmp['urlPlayer'];
	}
} elseif (str_contains($function, 'getImages')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
			    $all_files = glob("../images/upload/*.*");
			    $img = array();
			    for ($i=0; $i<count($all_files); $i++)
			    {
			        $image_name = $all_files[$i];
			        $supported_format = array('gif','jpg','jpeg','png');
			        $ext = strtolower(pathinfo($image_name, PATHINFO_EXTENSION));
			        if (in_array($ext, $supported_format))
			        {
			            array_push($img, $image_name);
			        } else {
			            continue;
			        }
			    }
			    header('Content-Type: application/json; charset=utf-8');
			    echo json_encode($img);
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'removeImage')) {
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$img = $data['img'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				if (file_exists($img)) {
	                if (unlink($img)) {
	                	echo 0;
	                }
	                else {
	                	echo -1;
	                }
	            }
	            else {
	            	echo -1; 
	            }
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
} elseif (str_contains($function, 'addPage')) {
	$data = $_POST['data'];
	$id = $data['id'];
	$nom = $data['nom'];
	$contenu = $data['contenu'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "users.json";
	$file_data = file_get_contents($file);
	//On admet qu'il y a au moins 1 utilisateur admin, car il est requis pour ajouter un utilisateur
	if(filesize($file)) {
		$tmp = json_decode($file_data, true);
		if(isset($tmp[$name]) && isset($tmp[$name]['pwd'])) {
			if(strcmp($tmp[$name]['pwd'], $pwd) == 0 && $tmp[$name]['admin']) {
				$tmp = json_decode(file_get_contents("db.json"), true);
				$tmp['pages'][$id]['nom'] = $nom;
				$tmp['pages'][$id]['contenu'] = $contenu;
				$new_data = json_encode($tmp);
				echo $new_data . ' ';
				$fp = fopen("db.json", 'w');
				echo fwrite($fp, $new_data);
				fclose($fp);
				echo 0;
			}
			else {
				echo -1;
			}
		}
		else {
			echo -1;
		}
	}
	else {
		echo -1;
	}
	$data = $_POST['data'];
	$name = $data['name'];
	$pwd = $data['pwd'];
	$file = "db.json";
	$data = file_get_contents($file);
	if(filesize($file)) {
		$tmp = json_decode($data, true);
		$tmp[$name] = $pwd;
		$data = json_encode($tmp);
	}
	else {
		$data = json_encode(array($name => $pwd));
	}
}
?>
